function [OutCellArray, Outconfig]=FreqMap_LPFilter(InCellArray, Inconfig)
%FreqMap_LPFilter will apply a low pass filter to the map and it requires
%an input for the desired cutoff frequency.
%
%Inputs: Frequency Map
%Outputs: Frequency Map
%
%Author: Ping Zhou, Michael Palmer
%Email: mikeppalmer@gmail.com
%
% Version history:
% 9/9/10 - Version 1
% 11/22/10 - Version 2

OutCellArray{1}=InCellArray{1};

xsize=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Max Frequency'),2};
ysize=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Max Frequency'),2};

xunit=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Unit'),2};
yunit=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Unit'),2};

% Max Frequency in X direction
xsize = str2num(xsize);
% Max Frequency in Y direction
ysize = str2num(ysize);

Outconfig=Inconfig;
validinputs=0;
f=Inconfig{strcmpi(Inconfig, 'f'),2};

%Get user input
if ~strcmpi(xunit, yunit)
    errordlg('Xunit and Yunit are not the same. Module Aborting');
    return;
end

while ~validinputs
    answers = inputdlg({['The cutoff frequency (', xunit, '): ']},'Input for cutoff frequency',1,{num2str(f)});
    if ~isempty(answers)
        tempf=answers{:};        
        tempf=str2num(tempf);
        if ~isempty(tempf)
            validinputs=1;           
            f=tempf;
        else
            msgbox('Please enter valid inputs','Invalid Inputs','warn','modal')
        end
    else
        OutCellArray={};
        return; %If answers is empty, user canceled
    end
end

Outconfig{strcmpi(Outconfig, 'f'),2}=num2str(f);
xi = linspace(-xsize, xsize, size(InCellArray{1}.data, 2));
yi = linspace(-ysize, ysize, size(InCellArray{1}.data, 1));
[Xi, Yi] = meshgrid(xi, yi);
R = sqrt(Xi.^2 + Yi.^2);

LPFilter = R<f;

data = InCellArray{1}.data;

OutCellArray{1}.data=data.*LPFilter;